package com.srs.dormitory.mapper;

import java.util.List;

import com.srs.dormitory.domain.DmsApprovalProcess;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Mapper;

/**
 * 宿舍管理审核Mapper接口
 *
 * @author srs
 * @date 2023-10-31
 */
@Mapper
public interface DmsApprovalProcessMapper extends BaseMapper<DmsApprovalProcess> {
    /**
     * 查询宿舍管理审核
     *
     * @param id 宿舍管理审核主键
     * @return 宿舍管理审核
     */
    public DmsApprovalProcess selectDmsApprovalProcessById(Long id);

    /**
     * 查询宿舍管理审核列表
     *
     * @param dmsApprovalProcess 宿舍管理审核
     * @return 宿舍管理审核集合
     */
    List<DmsApprovalProcess> selectDmsApprovalProcessList(DmsApprovalProcess dmsApprovalProcess);

    /**
     * 新增宿舍管理审核
     *
     * @param dmsApprovalProcess 宿舍管理审核
     * @return 结果
     */
    int insertDmsApprovalProcess(DmsApprovalProcess dmsApprovalProcess);

    /**
     * 修改宿舍管理审核
     *
     * @param dmsApprovalProcess 宿舍管理审核
     * @return 结果
     */
    int updateDmsApprovalProcess(DmsApprovalProcess dmsApprovalProcess);

    /**
     * 删除宿舍管理审核
     *
     * @param id 宿舍管理审核主键
     * @return 结果
     */
    int deleteDmsApprovalProcessById(Long id);

    /**
     * 批量删除宿舍管理审核
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteDmsApprovalProcessByIds(Long[] ids);
}
